Resources
^^^^^^^^^
* Follow the style of the :ref:`Ansible Documentation<ansible_documentation>`
* Ask for advice on the ``#ansible-devel`` chat channel (using Matrix at ansible.im or using IRC at `irc.libera.chat <https://libera.chat/>`_)
* Review these online style guides:

  * `AP Stylebook <https://www.apstylebook.com>`_
  * `Chicago Manual of Style <https://www.chicagomanualofstyle.org/home.html>`_
  * `Strunk and White's Elements of Style <https://www.crockford.com/wrrrld/style.html>`_
  * `Google developer documentation style guide <https://developers.google.com/style/highlights>`_

